@@ -492,6 +492,7 @@ class StorageInputs(object):
     no_virtual_trades: t.Optional[bool] = opt_field()
     initial_soe: t.Optional[float] = 0
     symmetric_reg: t.Optional[bool] = False
+    duration_requirement_on_discharge: t.Optional[bool] = opt_field()
     solver: t.Optional[bool] = opt_field()
 
 
@@ -530,6 +531,8 @@ class ReserveMarket(object):
     offer_cap: float
     utilization: t.Union[Utilization, TimeSeriesUtilization]
     obligation: t.Optional[t.List[float]] = opt_field()
+    duration_requirement: t.Optional[float] = opt_field()
+
 
 @dataclass_json
 @dataclass
